@@ -40,6 +40,7 @@ class Spreadclient:
         self.document = None
         self.sheet = None
         self.listed = None
+        self.verlisted = None
         self.commits = []
 
     @requirements_exists('client')
@@ -57,6 +58,7 @@ class Spreadclient:
             raise Exception(f"Document identifier did not fit one of the formats (key,name,url)")
 
         self.listed = None
+        self.verlisted = None
         self.sheet = None
         self.commits = []
 
@@ -84,6 +86,7 @@ class Spreadclient:
             self.sheet.update_cells(self.commits)
             self.commits = []
         self.listed = self.sheet.get_all_values()
+        self.verlisted = list(map(list, zip(*self.listed)))
 
     @requirements_exists('*')
     def get_row_by_column(self, value: Union[str, int], column: Union[str, int] = 0, refresh: bool = False)->list[Any]:
